"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCachedState = void 0;
var _react = require("react");
var _usePrevious = require("./usePrevious");
/**
 * Extends React.useState with a previous state as a first output value of array
 * @param initialValue initial value as the first value of the state and prevState
 * @returns [prevState, state, setState] - prevState is the previous state, state is the current state, setState is the setter for the state
 */
const useCachedState = initialValue => {
  const [state, setState] = (0, _react.useState)(initialValue);
  const prevState = (0, _usePrevious.usePrevious)(state);
  return [prevState, state, setState];
};
exports.useCachedState = useCachedState;
//# sourceMappingURL=useCachedState.js.map