import { useState } from 'react';
import { usePrevious } from './usePrevious';
/**
 * Extends React.useState with a previous state as a first output value of array
 * @param initialValue initial value as the first value of the state and prevState
 * @returns [prevState, state, setState] - prevState is the previous state, state is the current state, setState is the setter for the state
 */
export const useCachedState = initialValue => {
  const [state, setState] = useState(initialValue);
  const prevState = usePrevious(state);
  return [prevState, state, setState];
};
//# sourceMappingURL=useCachedState.js.map